pub fn check_mode_compatibility(
func: &FunctionSpec,
mode: Mode,
func_name: &str,
token: Option<&Token>,
) -> ParseResult<()>Expand description
Check if a mode is compatible with a function spec.
pub fn check_mode_compatibility(
func: &FunctionSpec,
mode: Mode,
func_name: &str,
token: Option<&Token>,
) -> ParseResult<()>Check if a mode is compatible with a function spec.