pub type FnMacroHandler = fn(&mut MacroExpander<'_>) -> ParseResult<Vec<Token>>;Expand description
Handler type for function-based macros (e.g. \TextOrMath, @ifstar). Takes the MacroExpander mutably and returns tokens to push onto the stack.
pub type FnMacroHandler = fn(&mut MacroExpander<'_>) -> ParseResult<Vec<Token>>;Handler type for function-based macros (e.g. \TextOrMath, @ifstar). Takes the MacroExpander mutably and returns tokens to push onto the stack.